# pisugar-server-py

Python library to communicate with pisugar-server.

## Requirements

python 3.5+

## Usage

Installation

    pip3 install pisugar

Python test code

    from pisugar import test_via_tcp

    test_via_tcp(<YOUR HOST ADDR>)

## License

Apache License
